/*
 * Copyright [2022] [https://www.baiduc.com]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.baiduc.com
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.baiduc.com
 */
package vip.xiaonuo.quality.controller;

import cn.dev33.satoken.annotation.SaCheckPermission;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import com.github.xiaoymin.knife4j.annotations.ApiSupport;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;
import vip.xiaonuo.common.annotation.CommonLog;
import vip.xiaonuo.common.pojo.CommonResult;

import vip.xiaonuo.common.pojo.CommonValidList;
import vip.xiaonuo.quality.entity.QualityFenxibaogao;
import vip.xiaonuo.quality.param.*;
import vip.xiaonuo.quality.param.vo.ChengPinQuXianVo;
import vip.xiaonuo.quality.service.QualityFenxibaogaoService;

import javax.annotation.Resource;
import javax.validation.Valid;
import javax.validation.constraints.NotEmpty;
import java.util.List;

/**
 * 质量分析报表控制器
 *
 * @author 1
 * @date  2025/02/26 16:25
 */
@Api(tags = "质量分析报表控制器")
@ApiSupport(author = "SNOWY_TEAM", order = 1)
@RestController
@Validated
public class QualityFenxibaogaoController {

    @Resource
    private QualityFenxibaogaoService qualityFenxibaogaoService;

    /**
     * 获取质量分析报表分页
     *
     * @author 1
     * @date  2025/02/26 16:25
     */
    @ApiOperationSupport(order = 1)
    @ApiOperation("获取质量分析报表分页")
    @PostMapping("/biz/fenxibaogao/page")
    public CommonResult<Page<QualityFenxibaogao>> page(QualityFenxibaogaoPageParam qualityFenxibaogaoPageParam) {
        return CommonResult.data(qualityFenxibaogaoService.page(qualityFenxibaogaoPageParam));
    }

    /**
     * 添加质量分析报表
     *
     * @author 1
     * @date  2025/02/26 16:25
     */
    @ApiOperationSupport(order = 2)
    @ApiOperation("添加质量分析报表")
    @PostMapping("/biz/fenxibaogao/add")
    public CommonResult<String> add(@RequestBody @Valid QualityFenxibaogaoAddParam qualityFenxibaogaoAddParam) {
        qualityFenxibaogaoService.add(qualityFenxibaogaoAddParam);
        return CommonResult.ok();
    }

    /**
     * 编辑质量分析报表
     *
     * @author 1
     * @date  2025/02/26 16:25
     */
    @ApiOperation("编辑质量分析报表")
    @PostMapping("/biz/fenxibaogao/edit")
    public CommonResult<String> edit(@RequestBody  QualityFenxibaogao qualityFenxibaogao) {
        qualityFenxibaogaoService.edit(qualityFenxibaogao);
        return CommonResult.ok();
    }

    /**
     * 删除质量分析报表
     *
     * @author 1
     * @date  2025/02/26 16:25
     */
    @ApiOperationSupport(order = 4)
    @ApiOperation("删除质量分析报表")
    @PostMapping("/biz/fenxibaogao/delete")
    public CommonResult<String> delete(@RequestBody QualityFenxibaogaoIdParam qualityFenxibaogaoIdParamList) {
        qualityFenxibaogaoService.delete(qualityFenxibaogaoIdParamList);
        return CommonResult.ok();
    }

    @ApiOperationSupport(order = 4)
    @ApiOperation("获取成品列表")
    @PostMapping("/biz/fenxibaogao/getChengPin")
    public CommonResult<List<QualityFenxibaogao>> getChengPin(@RequestBody ChengPingZhiParam chengPingZhiParam) {
        List<QualityFenxibaogao> list =   qualityFenxibaogaoService.getChengPin(chengPingZhiParam);
        return CommonResult.data(list);
    }

    @ApiOperationSupport(order = 4)
    @ApiOperation("获取检测项目列表")
    @PostMapping("/biz/fenxibaogao/getJianCeXiangMu")
    public CommonResult<List<QualityFenxibaogao>> getJianCeXiangMu(@RequestBody ChengPingZhiParam chengPingZhiParam) {
        List<QualityFenxibaogao> list =   qualityFenxibaogaoService.getJianCeXiangMu(chengPingZhiParam);
        return CommonResult.data(list);
    }

    @ApiOperationSupport(order = 4)
    @ApiOperation("获取成品中间体曲线")
    @PostMapping("/biz/fenxibaogao/getChengPinQuXian")
    public CommonResult<List<ChengPinQuXianVo>> getChengPinQuXian(@RequestBody ChengPingZhiParam chengPingZhiParam) {
        List<ChengPinQuXianVo> list =   qualityFenxibaogaoService.getChengPinQuXian(chengPingZhiParam);
        return CommonResult.data(list);
    }



}
